//
//  QueriesTableViewController.swift
//  Busca Pios
//
//  Created by Santiago Pavón on 18/12/14.
//  Copyright (c) 2014 UPM. All rights reserved.
//

import UIKit

class QueriesTableViewController: UITableViewController {

    
    // Fichero donde salvo las consultas
    private let SAVED_FILENAME = "queries.plist"
    
    // Las queries a mostrar en la tabla.
    var queries: [String]!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        
        self.navigationItem.leftBarButtonItem = editButtonItem
        
        loadQueries()
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    // MARK: - Table view data source
    
    override func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return queries.count
    }
    

    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "Query Cell", for: indexPath)
        
        cell.textLabel?.text = queries[indexPath.row]
        
        return cell
    }
    
    override func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        return "Selecciona una Consulta"
    }
    
    
    override func tableView(_ tableView: UITableView, titleForFooterInSection section: Int) -> String? {
        return "IWEB 2016/2017"
    }
    
    
    // Override to support editing the table view.
    override func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCellEditingStyle, forRowAt indexPath: IndexPath) {
        if editingStyle == .delete {
            
            queries.remove(at: indexPath.row)
            
            tableView.deleteRows(at: [indexPath], with: .fade)
            
            saveQueries()
            
        } else if editingStyle == .insert {
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
        }
    }
    
    // Override to support rearranging the table view.
    override func tableView(_ tableView: UITableView, moveRowAt fromIndexPath: IndexPath, to indexPath: IndexPath) {
        
        let aux = queries[fromIndexPath.row]
        
        queries.remove(at: fromIndexPath.row)
        queries.insert(aux, at: indexPath.row)
        
        saveQueries()
    }
    
    // Override to support conditional rearranging of the table view.
    override func tableView(_ tableView: UITableView, canMoveRowAt indexPath: IndexPath) -> Bool {
        return true
    }
    
    
    // MARK: Table View Delegate
    
    override func tableView(_ tableView: UITableView, titleForDeleteConfirmationButtonForRowAt indexPath: IndexPath) -> String? {
        return "ñam ñam"
    }
    
    // MARK: - Navigation
    
    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        
        if segue.identifier == "Show Query" {
            
            if let ttvc = segue.destination as? TweetsTableViewController {
                
                if let row = tableView.indexPath(for: sender as!UITableViewCell)?.row {
                    
                    ttvc.query = queries[row]
                }
            }
            
        } else if segue.identifier == "Add Query" {
            
            queries.insert("", at: 0)
            
            let ip = IndexPath(row: 0, section: 0)
            
            tableView.insertRows(at: [ip], with: UITableViewRowAnimation.right)
            
            tableView.selectRow(at: ip, animated: true, scrollPosition: .top)
            
            /*
            tableView.scrollToRowAtIndexPath(ip, atScrollPosition: UITableViewScrollPosition.Top, animated: true)
            */
            
            if let qevc = segue.destination as? QueryEditorViewController {
                
                qevc.query = ""
            }
            
        } else if segue.identifier == "Edit Query" {
            
            if let qevc = segue.destination as? QueryEditorViewController {
                
                if let ip = tableView.indexPath(for: sender as! UITableViewCell) {
                    
                    tableView.selectRow(at: ip, animated: true, scrollPosition: .top)
                    
                    qevc.query = queries[ip.row]
                }
            }
        }
    }
    
    
    @IBAction func queryWasEdited(_ segue: UIStoryboardSegue) {
        
        if let qevc = segue.source as? QueryEditorViewController {
            
            if let ip = tableView.indexPathForSelectedRow {
                
                queries[ip.row] = qevc.query
                
                tableView.reloadRows(at: [ip], with: .automatic)
                
                saveQueries()
            }
            
        }
    }
    
    // MARK: Persistencia
    
    private func getSavedQueriesPath() -> String {
        let path = NSSearchPathForDirectoriesInDomains(.documentDirectory,
            .userDomainMask, true)[0] 
        
        return (path as NSString).appendingPathComponent(SAVED_FILENAME)
    }
    
    
    private func loadQueries() {
        let path = getSavedQueriesPath()
        if let queries = NSArray(contentsOfFile: path) as? [String] {
            self.queries = queries
        } else {
            queries = ["Bachata","Tango","Merengue","Kizomba","Bolero",
                "Chachacha","Milonga","Vals"]
        }
    }
    
    private func saveQueries() {
        let path = getSavedQueriesPath()
        (queries as NSArray).write(toFile: path, atomically: true)
    }
}
